###UNESCO analyses
##Marc W Cadotte

dat<-read.csv("~/Documents/Marc2016/UNESCO/blog/UWH_stats.csv")

##linear models
#WHC and GDP
mod1<-lm(log(number)~log(GDP),dat)
AIC(mod1) #GDP best predictor

#WHC and POP
mod2<-lm(log(number)~log(POP_mill),dat)
AIC(mod2)

#WHC and AREA
mod3<-lm(log(number)~log(AREA_mill2km),dat)
AIC(mod3)

##univariate plots
#GDP
par(mfrow=c(1,3),cex.lab=1.5)
col<-c("rosybrown1","aliceblue","blue","grey","purple","aquamarine","red","brown","orange","lightblue", "black","thistle1")
reg<-unique(dat$region)

plot(log(dat$GDP), log(dat$number),xlab="Gross Domestic Product (log.GDP)", ylab="Number of World Heritage sites (log)",type='n')
for (i in 1:length(reg)) {
	points(x=log(dat$GDP[dat$region==reg[i]]), y=log(dat$number[dat$region==reg[i]]),col=col[i],pch=19,cex=1.5) 
	}
	
abline(mod1)
points(rep(log(exp(19)),length(col)),seq(log(exp(2)),log(exp(3.9)),length=length(col)),col=col,pch=19)
text(rep(log(exp(19)),length(col)),seq(log(exp(2)),log(exp(3.9)),length=length(col)),unique(dat$region), pos=4,cex=0.8)

#POP
plot(log(dat$AREA_mill2km), log(dat$number),xlab="Area (log millions km)", ylab="Number of World Heritage sites (log)",type='n')
for (i in 1:length(reg)) {
	points(x=log(dat$AREA_mill2km[dat$region==reg[i]]), y=log(dat$number[dat$region==reg[i]]),col=col[i],pch=19,cex=1.5) 
	}
	
abline(mod3)
#points(rep(log(exp(19)),length(col)),seq(log(exp(2)),log(exp(3.9)),length=length(col)),col=col,pch=19)
#text(rep(log(exp(19)),length(col)),seq(log(exp(2)),log(exp(3.9)),length=length(col)),unique(dat$region), pos=4,cex=0.8)

#Area
plot(log(dat$POP_mill), log(dat$number),xlab="Population (log millions)", ylab="Number of World Heritage sites (log)",type='n')
for (i in 1:length(reg)) {
	points(x=log(dat$POP_mill[dat$region==reg[i]]), y=log(dat$number[dat$region==reg[i]]),col=col[i],pch=19,cex=1.5) 
	}
	
abline(mod2)
#points(rep(log(exp(19)),length(col)),seq(log(exp(2)),log(exp(3.9)),length=length(col)),col=col,pch=19)
#text(rep(log(exp(19)),length(col)),seq(log(exp(2)),log(exp(3.9)),length=length(col)),unique(dat$region), pos=4,cex=0.8)


#GDP/POP -weaker relationship
mod4<-lm(log(number)~log(GDP.POP),dat)
plot(log(dat$GDP.POP), log(dat$number),xlab="Area (log millions km)", ylab="Number of World Heritage sites (log)",type='n')
for (i in 1:length(reg)) {
	points(x=log(dat$GDP.POP[dat$region==reg[i]]), y=log(dat$number[dat$region==reg[i]]),col=col[i],pch=19,cex=1.5) 
	}
	
abline(mod4)

#POP/Area -no relationship

mod5<-lm(log(number)~log(POP.AREA),dat)
plot(log(dat$POP.AREA), log(dat$number),xlab="Area (log millions km)", ylab="Number of World Heritage sites (log)",type='n')
for (i in 1:length(reg)) {
	points(x=log(dat$POP.AREA[dat$region==reg[i]]), y=log(dat$number[dat$region==reg[i]]),col=col[i],pch=19) 
	}
	
abline(mod5)

##multiple regression
library(car)
scatterplotMatrix(dat)  #not strongly correlated

mod.m<-lm(log(number)~log(GDP)+log(POP_mill)+log(AREA_mill2km),dat)
summary(mod.m)
AIC(mod.m)

mod.m2<-lm(log(number)~log(GDP)+log(POP_mill),dat)
summary(mod.m2)
AIC(mod.m2)

mod.m3<-lm(log(number)~log(GDP)*log(POP_mill),dat)
summary(mod.m3)
AIC(mod.m3)  #best model -as population increases, GDP becomes more important


resid<-mod.m3$residuals
names(resid)<-dat$place
resid<-resid[order(resid)]

cols<-NULL
for (i in 1:length(reg)){
	tmp<-dat[dat$region==reg[i],]
	cols[match(tmp$place,names(resid))]<-col[i]
	
}


barplot(resid,col=cols,names.arg=FALSE)

points(c(rep(120,6),rep(150,6)),rep(seq(-0.25,-1.25,length=6),2),col=col,pch=19)
text(c(rep(120,6),rep(150,6)),rep(seq(-0.25,-1.25,length=6),2),unique(dat$region), pos=4,cex=0.7)
text(120,1,"Over-represented",pos=4)
text(10,-1.2,"Under-represented",pos=4)


##histogram
hist(dat$number, col="aquamarine3",main=NULL,xlab="Number of World Heritage sites")


